/*
 * myListobj.cpp
 *
 *  Created on: Jun 30, 2014
 *      Author: nick
 */

#include "myListObj.h"
#include "myS3Common.h"

using namespace std;

extern bool initContext(const char* pszBucket, S3BucketContext& ctx);

static S3Status listBucketCallback(int isTruncated, const char *nextMarker,
                                   int contentsCount,
                                   const S3ListBucketContent *contents,
                                   int commonPrefixesCount,
                                   const char **commonPrefixes,
                                   void *callbackData)
{
	S3ObjVect* pVect = (S3ObjVect*)callbackData;
	for (int i = 0; i < contentsCount; i ++)
	{
		S3Obj obj;
		obj.key = trimQuote(contents[i].key);
		obj.size = contents[i].size;
		obj.tag = trimQuote(contents[i].eTag);
		obj.time = contents[i].lastModified;
		pVect->push_back(obj);
	}
	return S3StatusOK;
}



bool listObjectHelper(const S3BucketContext& ctx, const string& marker, S3ObjVect& s3List)
{
	S3ListBucketHandler handler =
			{ {&MyS3ResponsePropertiesCallback, &MyS3ResponseCompleteCallback}, &listBucketCallback};

	S3_list_bucket(&ctx, NULL, marker.c_str(), NULL, 990,
	                    NULL, &handler, &s3List);
	return true;
}

bool listObjects(const string& strBucket, S3ObjSet& s3List)
{
	S3BucketContext ctx;
	MyS3Context myS3;
	if (!myS3.initialize(strBucket.c_str(), ctx))
	{
		return false;
	}
	string marker = "/";
	while (true)
	{
		S3ObjVect vect;
		if (!listObjectHelper(ctx, marker, vect))
		{
			return false;
		}

		if (vect.size() == 0)
		{
			break;
		}
		s3List.insert(vect.begin(), vect.end());
		marker = vect[vect.size()-1].key;
	}
	return true;
}




